==> mozjs128_128.14.0.orig.tar.xz: firefox-128.14.0/testing/mozbase/mozdevice/mozdevice/version_codes.py <==
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this file,
# You can obtain one at http://mozilla.org/MPL/2.0/.

"""
VERSION CODES of the android releases.

See http://developer.android.com/reference/android/os/Build.VERSION_CODES.html.
"""
# Magic version number for a current development build, which has
# not yet turned into an official release.
CUR_DEVELOPMENT = 10000

# October 2008: The original, first, version of Android
BASE = 1
# February 2009: First Android update, officially called 1.1
BASE_1_1 = 2
# May 2009: Android 1.5
CUPCAKE = 3
# September 2009: Android 1.6
DONUT = 4
# November 2009: Android 2.0
ECLAIR = 5
# December 2009: Android 2.0.1
ECLAIR_0_1 = 6
# January 2010: Android 2.1
ECLAIR_MR1 = 7
# June 2010: Android 2.2
FROYO = 8
# November 2010: Android 2.3
GINGERBREAD = 9
# February 2011: Android 2.3.3
GINGERBREAD_MR1 = 10
# February 2011: Android 3.0
HONEYCOMB = 11
# May 2011: Android 3.1
HONEYCOMB_MR1 = 12
# June 2011: Android 3.2
HONEYCOMB_MR2 = 13
# October 2011: Android 4.0
ICE_CREAM_SANDWICH = 14
# December 2011: Android 4.0.3
ICE_CREAM_SANDWICH_MR1 = 15
# June 2012: Android 4.1
JELLY_BEAN = 16
# November 2012: Android 4.2
JELLY_BEAN_MR1 = 17
# July 2013: Android 4.3
JELLY_BEAN_MR2 = 18
# October 2013: Android 4.4
KITKAT = 19
# Android 4.4W
KITKAT_WATCH = 20
# Lollilop
LOLLIPOP = 21
LOLLIPOP_MR1 = 22
# Marshmallow
M = 23
# Nougat
N = 24
N_MR1 = 25
# Oreo
O = 26
O_MR1 = 27
# Pie
P = 28
# 10
Q = 29
# 11
R = 30

==> mozjs140_140.3.0.orig.tar.xz: firefox-140.3.0/testing/mozbase/mozdevice/mozdevice/version_codes.py <==
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this file,
# You can obtain one at http://mozilla.org/MPL/2.0/.

"""
VERSION CODES of the android releases.

See https://developer.android.com/reference/android/os/Build.VERSION_CODES.html.
"""
# Magic version number for a current development build, which has
# not yet turned into an official release.
CUR_DEVELOPMENT = 10000

# October 2008: The original, first, version of Android
BASE = 1
# February 2009: First Android update, officially called 1.1
BASE_1_1 = 2
# May 2009: Android 1.5
CUPCAKE = 3
# September 2009: Android 1.6
DONUT = 4
# November 2009: Android 2.0
ECLAIR = 5
# December 2009: Android 2.0.1
ECLAIR_0_1 = 6
# January 2010: Android 2.1
ECLAIR_MR1 = 7
# June 2010: Android 2.2
FROYO = 8
# November 2010: Android 2.3
GINGERBREAD = 9
# February 2011: Android 2.3.3
GINGERBREAD_MR1 = 10
# February 2011: Android 3.0
HONEYCOMB = 11
# May 2011: Android 3.1
HONEYCOMB_MR1 = 12
# June 2011: Android 3.2
HONEYCOMB_MR2 = 13
# October 2011: Android 4.0
ICE_CREAM_SANDWICH = 14
# December 2011: Android 4.0.3
ICE_CREAM_SANDWICH_MR1 = 15
# June 2012: Android 4.1
JELLY_BEAN = 16
# November 2012: Android 4.2
JELLY_BEAN_MR1 = 17
# July 2013: Android 4.3
JELLY_BEAN_MR2 = 18
# October 2013: Android 4.4
KITKAT = 19
# Android 4.4W
KITKAT_WATCH = 20
# 5 / 5.1 (Lollipop)
LOLLIPOP = 21
LOLLIPOP_MR1 = 22
# 6 (Marshmallow)
M = 23
# 7 / 7.1 (Nougat)
N = 24
N_MR1 = 25
# 8 / 8.1 (Oreo)
O = 26
O_MR1 = 27
# 9 (Pie)
P = 28
# 10 (Quince Tart)
Q = 29
# 11 (Red Velvet Cake)
R = 30
# 12 / 12L (Snow Cone)
S = 31
S_V2 = 32
# 13 (Tiramisu)
TIRAMISU = 33
# 14 (Upside Down Cake)
UPSIDE_DOWN_CAKE = 34
# 15 (Vanilla Ice Cream)
VANILLA_ICE_CREAM = 35
